# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.shopify_api import ShopifyApi


class TestShopifyApi(unittest.TestCase):
    """ShopifyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ShopifyApi()

    def tearDown(self) -> None:
        pass

    def test_customer_data_request(self) -> None:
        """Test case for customer_data_request

        Customer Data Request
        """
        pass

    def test_customer_redact(self) -> None:
        """Test case for customer_redact

        Customer Redact
        """
        pass

    def test_shop_redact(self) -> None:
        """Test case for shop_redact

        Shop Redact
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class TrackingEventSearchRequest(BaseModel):
    """
    TrackingEventSearchRequest
    """ # noqa: E501
    event_name: Optional[StrictStr] = None
    from_date: Optional[datetime] = None
    to_date: Optional[datetime] = None
    include_expired: Optional[StrictBool] = None
    page: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    page_size: Optional[Annotated[int, Field(le=100, strict=True, ge=1)]] = None
    __properties: ClassVar[List[str]] = ["event_name", "from_date", "to_date", "include_expired", "page", "page_size"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TrackingEventSearchRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if event_name (nullable) is None
        # and model_fields_set contains the field
        if self.event_name is None and "event_name" in self.model_fields_set:
            _dict['event_name'] = None

        # set to None if from_date (nullable) is None
        # and model_fields_set contains the field
        if self.from_date is None and "from_date" in self.model_fields_set:
            _dict['from_date'] = None

        # set to None if to_date (nullable) is None
        # and model_fields_set contains the field
        if self.to_date is None and "to_date" in self.model_fields_set:
            _dict['to_date'] = None

        # set to None if include_expired (nullable) is None
        # and model_fields_set contains the field
        if self.include_expired is None and "include_expired" in self.model_fields_set:
            _dict['include_expired'] = None

        # set to None if page (nullable) is None
        # and model_fields_set contains the field
        if self.page is None and "page" in self.model_fields_set:
            _dict['page'] = None

        # set to None if page_size (nullable) is None
        # and model_fields_set contains the field
        if self.page_size is None and "page_size" in self.model_fields_set:
            _dict['page_size'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TrackingEventSearchRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "event_name": obj.get("event_name"),
            "from_date": obj.get("from_date"),
            "to_date": obj.get("to_date"),
            "include_expired": obj.get("include_expired"),
            "page": obj.get("page"),
            "page_size": obj.get("page_size")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List
from typing import Optional, Set
from typing_extensions import Self

class ImageInferenceResponse(BaseModel):
    """
    ImageInferenceResponse
    """ # noqa: E501
    inference_id: StrictStr = Field(description="The ID of the inference")
    image_url_outputs: List[StrictStr] = Field(description="The URL of the image")
    date_created: datetime = Field(description="The date the image was created")
    prompt: StrictStr = Field(description="The prompt used for the inference")
    styles: List[StrictStr] = Field(description="The styles used for the inference")
    effects: List[StrictStr] = Field(description="The effects used for the inference")
    aspect_ratio: StrictStr = Field(description="The aspect ratio of the output images")
    ai_model: StrictStr = Field(description="The AI model used for the inference")
    status: StrictStr = Field(description="The status of the inference")
    __properties: ClassVar[List[str]] = ["inference_id", "image_url_outputs", "date_created", "prompt", "styles", "effects", "aspect_ratio", "ai_model", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ImageInferenceResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ImageInferenceResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "inference_id": obj.get("inference_id"),
            "image_url_outputs": obj.get("image_url_outputs"),
            "date_created": obj.get("date_created"),
            "prompt": obj.get("prompt"),
            "styles": obj.get("styles"),
            "effects": obj.get("effects"),
            "aspect_ratio": obj.get("aspect_ratio"),
            "ai_model": obj.get("ai_model"),
            "status": obj.get("status")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.url_screenshot_response import UrlScreenshotResponse
from typing import Optional, Set
from typing_extensions import Self

class ScheduleUrlResponse(BaseModel):
    """
    ScheduleUrlResponse
    """ # noqa: E501
    schedule_id: StrictStr
    domain_id: StrictStr
    url_id: StrictStr
    url: StrictStr
    last_text_timestamp: Optional[datetime]
    page_screenshot: Optional[UrlScreenshotResponse]
    url_title: Optional[StrictStr]
    url_meta_description: Optional[StrictStr]
    url_og_image: Optional[StrictStr]
    is_original_url: StrictBool
    dest_url_id: Optional[StrictStr]
    created_at: datetime
    __properties: ClassVar[List[str]] = ["schedule_id", "domain_id", "url_id", "url", "last_text_timestamp", "page_screenshot", "url_title", "url_meta_description", "url_og_image", "is_original_url", "dest_url_id", "created_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScheduleUrlResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of page_screenshot
        if self.page_screenshot:
            _dict['page_screenshot'] = self.page_screenshot.to_dict()
        # set to None if last_text_timestamp (nullable) is None
        # and model_fields_set contains the field
        if self.last_text_timestamp is None and "last_text_timestamp" in self.model_fields_set:
            _dict['last_text_timestamp'] = None

        # set to None if page_screenshot (nullable) is None
        # and model_fields_set contains the field
        if self.page_screenshot is None and "page_screenshot" in self.model_fields_set:
            _dict['page_screenshot'] = None

        # set to None if url_title (nullable) is None
        # and model_fields_set contains the field
        if self.url_title is None and "url_title" in self.model_fields_set:
            _dict['url_title'] = None

        # set to None if url_meta_description (nullable) is None
        # and model_fields_set contains the field
        if self.url_meta_description is None and "url_meta_description" in self.model_fields_set:
            _dict['url_meta_description'] = None

        # set to None if url_og_image (nullable) is None
        # and model_fields_set contains the field
        if self.url_og_image is None and "url_og_image" in self.model_fields_set:
            _dict['url_og_image'] = None

        # set to None if dest_url_id (nullable) is None
        # and model_fields_set contains the field
        if self.dest_url_id is None and "dest_url_id" in self.model_fields_set:
            _dict['dest_url_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScheduleUrlResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "schedule_id": obj.get("schedule_id"),
            "domain_id": obj.get("domain_id"),
            "url_id": obj.get("url_id"),
            "url": obj.get("url"),
            "last_text_timestamp": obj.get("last_text_timestamp"),
            "page_screenshot": UrlScreenshotResponse.from_dict(obj["page_screenshot"]) if obj.get("page_screenshot") is not None else None,
            "url_title": obj.get("url_title"),
            "url_meta_description": obj.get("url_meta_description"),
            "url_og_image": obj.get("url_og_image"),
            "is_original_url": obj.get("is_original_url"),
            "dest_url_id": obj.get("dest_url_id"),
            "created_at": obj.get("created_at")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.shop_redact_payload import ShopRedactPayload

class TestShopRedactPayload(unittest.TestCase):
    """ShopRedactPayload unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShopRedactPayload:
        """Test ShopRedactPayload
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShopRedactPayload`
        """
        model = ShopRedactPayload()
        if include_optional:
            return ShopRedactPayload(
                shop_id = 56,
                shop_domain = ''
            )
        else:
            return ShopRedactPayload(
                shop_id = 56,
                shop_domain = '',
        )
        """

    def testShopRedactPayload(self):
        """Test ShopRedactPayload"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.flow_assistant_api import FlowAssistantApi


class TestFlowAssistantApi(unittest.TestCase):
    """FlowAssistantApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FlowAssistantApi()

    def tearDown(self) -> None:
        pass

    def test_apply_flow_assistant_changes(self) -> None:
        """Test case for apply_flow_assistant_changes

        Apply Flow Assistant Changes
        """
        pass

    def test_create_flow_assistant_session(self) -> None:
        """Test case for create_flow_assistant_session

        Create Flow Assistant Session
        """
        pass

    def test_invoke_flow_assistant_response(self) -> None:
        """Test case for invoke_flow_assistant_response

        Invoke Flow Assistant Response
        """
        pass

    def test_poll_flow_assistant_response(self) -> None:
        """Test case for poll_flow_assistant_response

        Poll Flow Assistant Response
        """
        pass

    def test_reject_flow_assistant_changes(self) -> None:
        """Test case for reject_flow_assistant_changes

        Reject Flow Assistant Changes
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.chatbot_response import ChatbotResponse

class TestChatbotResponse(unittest.TestCase):
    """ChatbotResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatbotResponse:
        """Test ChatbotResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatbotResponse`
        """
        model = ChatbotResponse()
        if include_optional:
            return ChatbotResponse(
                workspace_id = '',
                chatbot_id = '',
                title = 'Tenant 1',
                description = '',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                status = 'A',
                url_suffix = '',
                theme = '',
                max_window_size = '',
                msg_rpm = 56,
                msg_ip_rpm = 56,
                chatbot_description = '',
                show_chatbot_header = True,
                chat_bubble_bg_color = '',
                chat_bubble_icon_color = '',
                chat_bubble_img_url = '',
                chatbot_theme = '',
                chatbot_position = '',
                message_placeholder = '',
                chatbot_header_text = '',
                chatbot_header_logo_url = '',
                assistant_avatar_image_url = '',
                remove_branding = True,
                chatbot_style = '',
                session_message_history = True,
                chatbot_bubble_size = 56,
                message_header_logo_url = ''
            )
        else:
            return ChatbotResponse(
                workspace_id = '',
                chatbot_id = '',
                title = 'Tenant 1',
                flow_id = 'a0eebc99-9c0b-4ef8-bb6d-6bb9bd380a11',
                status = 'A',
        )
        """

    def testChatbotResponse(self):
        """Test ChatbotResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AspecRatio(str, Enum):
    """
    AspecRatio
    """

    """
    allowed enum values
    """
    ENUM_1_COLON_1 = '1:1'
    ENUM_16_COLON_9 = '16:9'
    ENUM_21_COLON_9 = '21:9'
    ENUM_3_COLON_2 = '3:2'
    ENUM_2_COLON_3 = '2:3'
    ENUM_4_COLON_5 = '4:5'
    ENUM_5_COLON_4 = '5:4'
    ENUM_3_COLON_4 = '3:4'
    ENUM_4_COLON_3 = '4:3'
    ENUM_9_COLON_16 = '9:16'
    ENUM_9_COLON_21 = '9:21'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AspecRatio from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.google_ads_action_type import GoogleAdsActionType
from flowhunt.models.google_ads_campaign_status import GoogleAdsCampaignStatus
from typing import Optional, Set
from typing_extensions import Self

class GoogleAdsCampaignResponse(BaseModel):
    """
    GoogleAdsCampaignResponse
    """ # noqa: E501
    workspace_id: StrictStr = Field(description="Workspace ID")
    customer_id: StrictStr = Field(description="Google Ads Customer ID")
    campaign_id: StrictStr = Field(description="Google Ads Campaign ID")
    campaign_name: StrictStr = Field(description="Google Ads Campaign Name")
    campaign_status: GoogleAdsCampaignStatus = Field(description="Campaign Status")
    language_code: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    last_update: Optional[datetime] = None
    action_type: GoogleAdsActionType = Field(description="Action Type")
    __properties: ClassVar[List[str]] = ["workspace_id", "customer_id", "campaign_id", "campaign_name", "campaign_status", "language_code", "country", "last_update", "action_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GoogleAdsCampaignResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if language_code (nullable) is None
        # and model_fields_set contains the field
        if self.language_code is None and "language_code" in self.model_fields_set:
            _dict['language_code'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if last_update (nullable) is None
        # and model_fields_set contains the field
        if self.last_update is None and "last_update" in self.model_fields_set:
            _dict['last_update'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GoogleAdsCampaignResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "workspace_id": obj.get("workspace_id"),
            "customer_id": obj.get("customer_id"),
            "campaign_id": obj.get("campaign_id"),
            "campaign_name": obj.get("campaign_name"),
            "campaign_status": obj.get("campaign_status"),
            "language_code": obj.get("language_code"),
            "country": obj.get("country"),
            "last_update": obj.get("last_update"),
            "action_type": obj.get("action_type")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.mcp_server_response import MCPServerResponse

class TestMCPServerResponse(unittest.TestCase):
    """MCPServerResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MCPServerResponse:
        """Test MCPServerResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MCPServerResponse`
        """
        model = MCPServerResponse()
        if include_optional:
            return MCPServerResponse(
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                mcp_server_id = '0x1d230dabdb5bc7cb',
                name = 'My MCP Server',
                server_configuration = [
                    flowhunt.models.mcp_sub_server_binding.MCPSubServerBinding(
                        subserver_id = '', 
                        capabilities = [
                            flowhunt.models.mcp_capability_binding.MCPCapabilityBinding(
                                capability_id = '', )
                            ], )
                    ],
                is_active = True,
                created_at = '2021-05-07T12:34:56.789Z',
                updated_at = '2021-05-07T12:34:56.789Z',
                remote_mcp_url = ''
            )
        else:
            return MCPServerResponse(
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                mcp_server_id = '0x1d230dabdb5bc7cb',
                name = 'My MCP Server',
                server_configuration = [
                    flowhunt.models.mcp_sub_server_binding.MCPSubServerBinding(
                        subserver_id = '', 
                        capabilities = [
                            flowhunt.models.mcp_capability_binding.MCPCapabilityBinding(
                                capability_id = '', )
                            ], )
                    ],
                is_active = True,
                created_at = '2021-05-07T12:34:56.789Z',
                updated_at = '2021-05-07T12:34:56.789Z',
        )
        """

    def testMCPServerResponse(self):
        """Test MCPServerResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.tracking_event_create_requests import TrackingEventCreateRequests

class TestTrackingEventCreateRequests(unittest.TestCase):
    """TrackingEventCreateRequests unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrackingEventCreateRequests:
        """Test TrackingEventCreateRequests
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrackingEventCreateRequests`
        """
        model = TrackingEventCreateRequests()
        if include_optional:
            return TrackingEventCreateRequests(
                events = [
                    flowhunt.models.tracking_event_create_request.TrackingEventCreateRequest(
                        event_name = '', 
                        unique_id = '', 
                        event_value = 1.337, 
                        currency = '', 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        link_ids = [
                            ''
                            ], 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conversion_action_id = '', 
                        include_in_conversions_metric = True, 
                        url = '', )
                    ],
                unique_id = '',
                fp = '',
                session_id = '',
                with_address = True,
                ga = ''
            )
        else:
            return TrackingEventCreateRequests(
                events = [
                    flowhunt.models.tracking_event_create_request.TrackingEventCreateRequest(
                        event_name = '', 
                        unique_id = '', 
                        event_value = 1.337, 
                        currency = '', 
                        event_data = [
                            flowhunt.models.tracking_event_data.TrackingEventData(
                                key = '', 
                                value_text = '', 
                                value_number = 1.337, 
                                value_boolean = True, 
                                value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        link_ids = [
                            ''
                            ], 
                        valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        conversion_action_id = '', 
                        include_in_conversions_metric = True, 
                        url = '', )
                    ],
        )
        """

    def testTrackingEventCreateRequests(self):
        """Test TrackingEventCreateRequests"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DocumentType(str, Enum):
    """
    DocumentType
    """

    """
    allowed enum values
    """
    PDF = 'PDF'
    DOCX = 'DOCX'
    MD = 'MD'
    TXT = 'TXT'
    HTML = 'HTML'
    YT = 'YT'
    UN = 'UN'
    MP3 = 'MP3'
    FLAC = 'FLAC'
    MP4 = 'MP4'
    MPEG = 'MPEG'
    MPGA = 'MPGA'
    M4A = 'M4A'
    OGG = 'OGG'
    WAV = 'WAV'
    WEBM = 'WEBM'
    JPEG = 'JPEG'
    JPG = 'JPG'
    PNG = 'PNG'
    GIF = 'GIF'
    WEBP = 'WEBP'
    CSV = 'CSV'
    XML = 'XML'
    JSON = 'JSON'
    GOOGLE_DOCS = 'GOOGLE_DOCS'
    GOOGLE_SHEETS = 'GOOGLE_SHEETS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DocumentType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.microsoft_outlook_api import MicrosoftOutlookApi


class TestMicrosoftOutlookApi(unittest.TestCase):
    """MicrosoftOutlookApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MicrosoftOutlookApi()

    def tearDown(self) -> None:
        pass

    def test_update_admin_consent(self) -> None:
        """Test case for update_admin_consent

        Update Admin Consent
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.schedule_response import ScheduleResponse

class TestScheduleResponse(unittest.TestCase):
    """ScheduleResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScheduleResponse:
        """Test ScheduleResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScheduleResponse`
        """
        model = ScheduleResponse()
        if include_optional:
            return ScheduleResponse(
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                schedule_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                url = 'https://example.com',
                frequency = D,
                schedule_type = D,
                start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                status = N,
                status_message = '',
                cnt_scheduled = 56,
                cnt_completed = 56,
                cnt_failed = 56,
                with_screenshot = 'Y',
                with_browser = 'Y',
                follow_links = 'Y',
                with_proxy_rotation = 'Y',
                disallow_urls = '',
                filter_urls = '',
                custom_headers = ''
            )
        else:
            return ScheduleResponse(
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                schedule_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                url = 'https://example.com',
                frequency = D,
                schedule_type = D,
                status = N,
                cnt_scheduled = 56,
                cnt_completed = 56,
                cnt_failed = 56,
                with_screenshot = 'Y',
                with_browser = 'Y',
                follow_links = 'Y',
                with_proxy_rotation = 'Y',
        )
        """

    def testScheduleResponse(self):
        """Test ScheduleResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.data import Data

class TestData(unittest.TestCase):
    """Data unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Data:
        """Test Data
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Data`
        """
        model = Data()
        if include_optional:
            return Data(
                schedule_id = '',
                domain_id = '',
                url_id = '',
                url = '',
                last_text_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                page_screenshot = flowhunt.models.url_screenshot_response.UrlScreenshotResponse(
                    original_image = '', 
                    thumbnail_image = '', 
                    original_image_full_page = '', 
                    thumbnail_image_full_page = '', ),
                url_title = '',
                url_meta_description = '',
                url_og_image = '',
                is_original_url = True,
                dest_url_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url_text = [
                    {
                        'key' : ''
                        }
                    ],
                faq_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                cat_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                question = 'What is LiveAgent?',
                answer = '',
                parent_faq_id = '',
                status = 'N',
                updated_at = '2021-01-01T00:00:00',
                indexed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                doc_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                doc_name = 'Document name',
                doc_type = 'PDF',
                user_status = 'N'
            )
        else:
            return Data(
                schedule_id = '',
                domain_id = '',
                url_id = '',
                url = '',
                last_text_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                page_screenshot = flowhunt.models.url_screenshot_response.UrlScreenshotResponse(
                    original_image = '', 
                    thumbnail_image = '', 
                    original_image_full_page = '', 
                    thumbnail_image_full_page = '', ),
                url_title = '',
                url_meta_description = '',
                url_og_image = '',
                is_original_url = True,
                dest_url_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                url_text = [
                    {
                        'key' : ''
                        }
                    ],
                faq_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                workspace_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                cat_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                question = 'What is LiveAgent?',
                status = 'N',
                updated_at = '2021-01-01T00:00:00',
                doc_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384',
                doc_name = 'Document name',
                doc_type = 'PDF',
                user_status = 'N',
        )
        """

    def testData(self):
        """Test Data"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.google_api import GoogleApi


class TestGoogleApi(unittest.TestCase):
    """GoogleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GoogleApi()

    def tearDown(self) -> None:
        pass

    def test_get_calendars(self) -> None:
        """Test case for get_calendars

        Get Calendars
        """
        pass

    def test_get_picker_token(self) -> None:
        """Test case for get_picker_token

        Get Picker Token
        """
        pass

    def test_get_sheets(self) -> None:
        """Test case for get_sheets

        Get Sheets
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_version_history_response import FlowVersionHistoryResponse

class TestFlowVersionHistoryResponse(unittest.TestCase):
    """FlowVersionHistoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowVersionHistoryResponse:
        """Test FlowVersionHistoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowVersionHistoryResponse`
        """
        model = FlowVersionHistoryResponse()
        if include_optional:
            return FlowVersionHistoryResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                version_nr = 56,
                flow_type = p,
                executed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                category_id = '',
                enable_cache = True,
                user = flowhunt.models.user_response.UserResponse(
                    user_id = 'd719f5f5-5433-4cb4-9993-8053bda1a384', 
                    email = 'test@test.com', 
                    username = 'John Doe', 
                    is_active = True, 
                    avatar_url = '', 
                    api_key_workspace_id = '', 
                    product_plans = {
                        'key' : 'S'
                        }, ),
                branch = 'P',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                commit_title = ''
            )
        else:
            return FlowVersionHistoryResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                flow_type = p,
                enable_cache = True,
                branch = 'P',
        )
        """

    def testFlowVersionHistoryResponse(self):
        """Test FlowVersionHistoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.images_api import ImagesApi


class TestImagesApi(unittest.TestCase):
    """ImagesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ImagesApi()

    def tearDown(self) -> None:
        pass

    def test_convert_image(self) -> None:
        """Test case for convert_image

        Convert Image
        """
        pass

    def test_get_screenshot(self) -> None:
        """Test case for get_screenshot

        Get Screenshot
        """
        pass

    def test_optimize_image(self) -> None:
        """Test case for optimize_image

        Optimize Image
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.image_ft_update_request import ImageFTUpdateRequest

class TestImageFTUpdateRequest(unittest.TestCase):
    """ImageFTUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageFTUpdateRequest:
        """Test ImageFTUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageFTUpdateRequest`
        """
        model = ImageFTUpdateRequest()
        if include_optional:
            return ImageFTUpdateRequest(
                name = 'Fine tuning 1',
                steps = 56,
                lora_rank = 56,
                training_images = [image1.jpg, image2.jpg],
                cover_image = 'cover.jpg'
            )
        else:
            return ImageFTUpdateRequest(
                name = 'Fine tuning 1',
                training_images = [image1.jpg, image2.jpg],
                cover_image = 'cover.jpg',
        )
        """

    def testImageFTUpdateRequest(self):
        """Test ImageFTUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.billing_api import BillingApi


class TestBillingApi(unittest.TestCase):
    """BillingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BillingApi()

    def tearDown(self) -> None:
        pass

    def test_add_addon_to_subscription(self) -> None:
        """Test case for add_addon_to_subscription

        Add Addon To Subscription
        """
        pass

    def test_create_change_plan_portal(self) -> None:
        """Test case for create_change_plan_portal

        Create Change Plan Portal
        """
        pass

    def test_create_checkout(self) -> None:
        """Test case for create_checkout

        Create Checkout
        """
        pass

    def test_create_update_info_portal(self) -> None:
        """Test case for create_update_info_portal

        Create Update Info Portal
        """
        pass

    def test_get_pricing_plans(self) -> None:
        """Test case for get_pricing_plans

        Get Pricing Plans
        """
        pass

    def test_get_user_plan(self) -> None:
        """Test case for get_user_plan

        Get User Plan
        """
        pass

    def test_stripe_webhook(self) -> None:
        """Test case for stripe_webhook

        Stripe Webhook
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FlowEventActionType(str, Enum):
    """
    FlowEventActionType
    """

    """
    allowed enum values
    """
    LOADING = 'loading'
    MESSAGE = 'message'
    TOOL_CALL = 'tool_call'
    TASK_RESPONSE = 'task_response'
    FAILED = 'failed'
    ADD_COMPONENT = 'add_component'
    DELETE_COMPONENT = 'delete_component'
    CONNECT_COMPONENTS = 'connect_components'
    UPDATE_COMPONENT = 'update_component'
    ADD_CONNECTION = 'add_connection'
    DELETE_CONNECTION = 'delete_connection'
    CREATE_BLANK_FLOW = 'create_blank_flow'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FlowEventActionType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Optional
from flowhunt.models.flow_assistant_add_component_metadata import FlowAssistantAddComponentMetadata
from flowhunt.models.flow_assistant_add_connection_metadata import FlowAssistantAddConnectionMetadata
from flowhunt.models.flow_assistant_create_blank_flow_metadata import FlowAssistantCreateBlankFlowMetadata
from flowhunt.models.flow_assistant_delete_component_metadata import FlowAssistantDeleteComponentMetadata
from flowhunt.models.flow_assistant_delete_connection_metadata import FlowAssistantDeleteConnectionMetadata
from flowhunt.models.flow_assistant_update_component_metadata import FlowAssistantUpdateComponentMetadata
from flowhunt.models.flow_session_loading_metadata import FlowSessionLoadingMetadata
from flowhunt.models.flow_session_message_metadata import FlowSessionMessageMetadata
from flowhunt.models.flow_session_task_response_metadata import FlowSessionTaskResponseMetadata
from flowhunt.models.flow_session_tool_call_metadata import FlowSessionToolCallMetadata
from typing import Union, Any, List, Set, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal, Self
from pydantic import Field

METADATA_ANY_OF_SCHEMAS = ["FlowAssistantAddComponentMetadata", "FlowAssistantAddConnectionMetadata", "FlowAssistantCreateBlankFlowMetadata", "FlowAssistantDeleteComponentMetadata", "FlowAssistantDeleteConnectionMetadata", "FlowAssistantUpdateComponentMetadata", "FlowSessionLoadingMetadata", "FlowSessionMessageMetadata", "FlowSessionTaskResponseMetadata", "FlowSessionToolCallMetadata"]

class Metadata(BaseModel):
    """
    Metadata
    """

    # data type: FlowSessionMessageMetadata
    anyof_schema_1_validator: Optional[FlowSessionMessageMetadata] = None
    # data type: FlowSessionLoadingMetadata
    anyof_schema_2_validator: Optional[FlowSessionLoadingMetadata] = None
    # data type: FlowSessionToolCallMetadata
    anyof_schema_3_validator: Optional[FlowSessionToolCallMetadata] = None
    # data type: FlowSessionTaskResponseMetadata
    anyof_schema_4_validator: Optional[FlowSessionTaskResponseMetadata] = None
    # data type: FlowAssistantAddComponentMetadata
    anyof_schema_5_validator: Optional[FlowAssistantAddComponentMetadata] = None
    # data type: FlowAssistantDeleteComponentMetadata
    anyof_schema_6_validator: Optional[FlowAssistantDeleteComponentMetadata] = None
    # data type: FlowAssistantUpdateComponentMetadata
    anyof_schema_7_validator: Optional[FlowAssistantUpdateComponentMetadata] = None
    # data type: FlowAssistantAddConnectionMetadata
    anyof_schema_8_validator: Optional[FlowAssistantAddConnectionMetadata] = None
    # data type: FlowAssistantDeleteConnectionMetadata
    anyof_schema_9_validator: Optional[FlowAssistantDeleteConnectionMetadata] = None
    # data type: FlowAssistantCreateBlankFlowMetadata
    anyof_schema_10_validator: Optional[FlowAssistantCreateBlankFlowMetadata] = None
    if TYPE_CHECKING:
        actual_instance: Optional[Union[FlowAssistantAddComponentMetadata, FlowAssistantAddConnectionMetadata, FlowAssistantCreateBlankFlowMetadata, FlowAssistantDeleteComponentMetadata, FlowAssistantDeleteConnectionMetadata, FlowAssistantUpdateComponentMetadata, FlowSessionLoadingMetadata, FlowSessionMessageMetadata, FlowSessionTaskResponseMetadata, FlowSessionToolCallMetadata]] = None
    else:
        actual_instance: Any = None
    any_of_schemas: Set[str] = { "FlowAssistantAddComponentMetadata", "FlowAssistantAddConnectionMetadata", "FlowAssistantCreateBlankFlowMetadata", "FlowAssistantDeleteComponentMetadata", "FlowAssistantDeleteConnectionMetadata", "FlowAssistantUpdateComponentMetadata", "FlowSessionLoadingMetadata", "FlowSessionMessageMetadata", "FlowSessionTaskResponseMetadata", "FlowSessionToolCallMetadata" }

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_anyof(cls, v):
        if v is None:
            return v

        instance = Metadata.model_construct()
        error_messages = []
        # validate data type: FlowSessionMessageMetadata
        if not isinstance(v, FlowSessionMessageMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowSessionMessageMetadata`")
        else:
            return v

        # validate data type: FlowSessionLoadingMetadata
        if not isinstance(v, FlowSessionLoadingMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowSessionLoadingMetadata`")
        else:
            return v

        # validate data type: FlowSessionToolCallMetadata
        if not isinstance(v, FlowSessionToolCallMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowSessionToolCallMetadata`")
        else:
            return v

        # validate data type: FlowSessionTaskResponseMetadata
        if not isinstance(v, FlowSessionTaskResponseMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowSessionTaskResponseMetadata`")
        else:
            return v

        # validate data type: FlowAssistantAddComponentMetadata
        if not isinstance(v, FlowAssistantAddComponentMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantAddComponentMetadata`")
        else:
            return v

        # validate data type: FlowAssistantDeleteComponentMetadata
        if not isinstance(v, FlowAssistantDeleteComponentMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantDeleteComponentMetadata`")
        else:
            return v

        # validate data type: FlowAssistantUpdateComponentMetadata
        if not isinstance(v, FlowAssistantUpdateComponentMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantUpdateComponentMetadata`")
        else:
            return v

        # validate data type: FlowAssistantAddConnectionMetadata
        if not isinstance(v, FlowAssistantAddConnectionMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantAddConnectionMetadata`")
        else:
            return v

        # validate data type: FlowAssistantDeleteConnectionMetadata
        if not isinstance(v, FlowAssistantDeleteConnectionMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantDeleteConnectionMetadata`")
        else:
            return v

        # validate data type: FlowAssistantCreateBlankFlowMetadata
        if not isinstance(v, FlowAssistantCreateBlankFlowMetadata):
            error_messages.append(f"Error! Input type `{type(v)}` is not `FlowAssistantCreateBlankFlowMetadata`")
        else:
            return v

        if error_messages:
            # no match
            raise ValueError("No match found when setting the actual_instance in Metadata with anyOf schemas: FlowAssistantAddComponentMetadata, FlowAssistantAddConnectionMetadata, FlowAssistantCreateBlankFlowMetadata, FlowAssistantDeleteComponentMetadata, FlowAssistantDeleteConnectionMetadata, FlowAssistantUpdateComponentMetadata, FlowSessionLoadingMetadata, FlowSessionMessageMetadata, FlowSessionTaskResponseMetadata, FlowSessionToolCallMetadata. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        if json_str is None:
            return instance

        error_messages = []
        # anyof_schema_1_validator: Optional[FlowSessionMessageMetadata] = None
        try:
            instance.actual_instance = FlowSessionMessageMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_2_validator: Optional[FlowSessionLoadingMetadata] = None
        try:
            instance.actual_instance = FlowSessionLoadingMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_3_validator: Optional[FlowSessionToolCallMetadata] = None
        try:
            instance.actual_instance = FlowSessionToolCallMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_4_validator: Optional[FlowSessionTaskResponseMetadata] = None
        try:
            instance.actual_instance = FlowSessionTaskResponseMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_5_validator: Optional[FlowAssistantAddComponentMetadata] = None
        try:
            instance.actual_instance = FlowAssistantAddComponentMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_6_validator: Optional[FlowAssistantDeleteComponentMetadata] = None
        try:
            instance.actual_instance = FlowAssistantDeleteComponentMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_7_validator: Optional[FlowAssistantUpdateComponentMetadata] = None
        try:
            instance.actual_instance = FlowAssistantUpdateComponentMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_8_validator: Optional[FlowAssistantAddConnectionMetadata] = None
        try:
            instance.actual_instance = FlowAssistantAddConnectionMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_9_validator: Optional[FlowAssistantDeleteConnectionMetadata] = None
        try:
            instance.actual_instance = FlowAssistantDeleteConnectionMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_10_validator: Optional[FlowAssistantCreateBlankFlowMetadata] = None
        try:
            instance.actual_instance = FlowAssistantCreateBlankFlowMetadata.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError("No match found when deserializing the JSON string into Metadata with anyOf schemas: FlowAssistantAddComponentMetadata, FlowAssistantAddConnectionMetadata, FlowAssistantCreateBlankFlowMetadata, FlowAssistantDeleteComponentMetadata, FlowAssistantDeleteConnectionMetadata, FlowAssistantUpdateComponentMetadata, FlowSessionLoadingMetadata, FlowSessionMessageMetadata, FlowSessionTaskResponseMetadata, FlowSessionToolCallMetadata. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], FlowAssistantAddComponentMetadata, FlowAssistantAddConnectionMetadata, FlowAssistantCreateBlankFlowMetadata, FlowAssistantDeleteComponentMetadata, FlowAssistantDeleteConnectionMetadata, FlowAssistantUpdateComponentMetadata, FlowSessionLoadingMetadata, FlowSessionMessageMetadata, FlowSessionTaskResponseMetadata, FlowSessionToolCallMetadata]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.vector_document_response import VectorDocumentResponse

class TestVectorDocumentResponse(unittest.TestCase):
    """VectorDocumentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VectorDocumentResponse:
        """Test VectorDocumentResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VectorDocumentResponse`
        """
        model = VectorDocumentResponse()
        if include_optional:
            return VectorDocumentResponse(
                document_id = '00000000-0000-0000-0000-000000000000',
                workspace_id = '00000000-0000-0000-0000-000000000000',
                document_type = U,
                point_id = '00000000-0000-0000-0000-000000000000',
                pointer_position = 1,
                pointer_type = C,
                schema_type = '',
                kb_key = '00000000-0000-0000-0000-000000000000',
                vector = [
                    1.337
                    ],
                vector_id = 0,
                data = None
            )
        else:
            return VectorDocumentResponse(
                document_id = '00000000-0000-0000-0000-000000000000',
                workspace_id = '00000000-0000-0000-0000-000000000000',
                document_type = U,
                point_id = '00000000-0000-0000-0000-000000000000',
                pointer_position = 1,
                pointer_type = C,
                kb_key = '00000000-0000-0000-0000-000000000000',
                vector = [
                    1.337
                    ],
                vector_id = 0,
        )
        """

    def testVectorDocumentResponse(self):
        """Test VectorDocumentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
